//=============================================================================
//  MuseScore
//  Linux Music Score Editor
//  $Id:$
//
//  Copy Rhythm plugin
//
//  Copyright (C)2013 Colin Whyles
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

var readStaff;					// The staff we are reading from
var chordList = [];				// We copy the input chords here
// The Copy Rhythm-Paste Rhythm pair of plugins depend on MuseScore not cleaning up between plugins,
// so chordList can be populated by Copy Rhythm and later read by Past Rhythm.

//---------------------------------------------------------
//    init
//---------------------------------------------------------

function init() {
};

//---------------------------------------------------------
//    close
//---------------------------------------------------------

function close() {
};

//---------------------------------------------------------
// readVoice()
// Read a voice into the chordList array
//---------------------------------------------------------
function readVoice(voice) {
	var tick = 0;
	var cursor = new Cursor(curScore);
	cursor.staff = 0;			// gets set to selected staff when the selection is found.
	cursor.rewind();
	
	//  Bound the selection
	cursor.goToSelectionStart();
	cursor.voice = voice;
	readStaff = cursor.staff;		// Note the staff we are reading from!
	var selnEnd = new Cursor(curScore);
	selnEnd.goToSelectionEnd();
	selnEnd.voice = voice;

	//  Read notes and rests into chordList array
	var tickCnt = cursor.tick();
	tick = 0;
	chordList = [];
	while (cursor.tick() < selnEnd.tick())
	{
		//  Read in the chords and rests etc.
		if (cursor.isChord()) {
			var chrd = cursor.chord();
			chordList.push(chrd.tickLen);
			tick++;
		} else if (cursor.isRest()) {
			var rest = cursor.rest();                    
			chordList.push(rest.tickLen);
			tick++;
		}
		cursor.next();
	}
	cursor.rewind();
}

//---------------------------------------------------------
//    copyRhythm
//---------------------------------------------------------

function copyRhythm() {
	//  Bounce if not a proper score
	if (typeof curScore === 'undefined') 
		return; 

	//  Bound the selection
	var cursor = new Cursor(curScore);
	cursor.rewind();
	cursor.goToSelectionEnd();
	if (cursor.eos() == true) {
		QMessageBox.information(this, "No Selection", qsTr("<b>No selection made.</b> <br>Select a range of measures that have the rhythm you require and open Copy Rhythm. When prompted, select OK and select the measures where you want to paste the rhythm and select Paste Rhythm.."));
		return;		// No selection made.
	}
	
	readVoice(0);	// Issue: How do we know which voice to copy rhythm from?
	QMessageBox.information(this, "Rhythm copied", qsTr("<b>Rhythm copied.</b> <br>Select OK then select the measures where you want the rhythm copied to and open Paste Rhythm."));

	close();
};
//---------------------------------------------------------

var mscorePlugin = {
      menu: 'Plugins.Copy Rhythm',
      init: init,
      run:  copyRhythm,
      onClose: close
      };

mscorePlugin;