//=============================================================================
//  MuseScore
//  Linux Music Score Editor
//  $Id:$
//
//  Clone Rhythm plugin
//
//  Copyright (C)2013 Colin Whyles
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

//var readStaff;					// The staff we are reading from
//var chordList = [];				// We copy the input chords here
//var tickList = [];				// Where the chords and rests fall. 
								// We need this because the cursor in MuseScore doesn't seem 
								// to only act on a single voice. It acts on the smallest division among all voices.

//---------------------------------------------------------
//    init
//---------------------------------------------------------

function init() {
};

//---------------------------------------------------------
//    close
//---------------------------------------------------------

function close() {
	chordList = [];
};

//---------------------------------------------------------
//    pasteRhythm
//---------------------------------------------------------

function pasteRhythm() {
	//  Bounce if not a proper score
	if (typeof curScore === 'undefined') 
		return; 
	if (typeof chordList === 'undefined' || chordList.length == 0) {
		QMessageBox.warning(this, "No Rhythm Copied", qsTr("<b>No rhythm copied.</b> <br>Select a range of measures that have the rhythm you require and open Copy Rhythm. When prompted, select OK and select the measures where you want to paste the rhythm and select Paste Rhythm."));
		return;
	}
	
	//  Bound the selection
	var cursor = new Cursor(curScore);
	cursor.rewind();
	cursor.goToSelectionEnd();
	if (cursor.eos() == true) {
		QMessageBox.information(this, "No Selection", qsTr("<b>No selection made.</b> <br>Select a range of measures that have the rhythm you require and open Copy Rhythm. When prompted, select OK and select the measures where you want to paste the rhythm and select Paste Rhythm."));
		return;		// No selection made.
	}

	curScore.startUndo();
	cursor.goToSelectionStart();
	// Paste the rhythms to the parts
	//cursor.voice = 0;				// Copy them from voiceIn
	//cursor.staff = readStaff;		// Follow the staff we have read from

	for (var tick = 0; tick < chordList.length; tick++) {
		// Copy rhythms
		if (cursor.isChord()) {
			cursor.chord().tickLen = chordList[tick];
		} else if (cursor.isRest()) {
			cursor.rest().tickLen = chordList[tick];
		}
		cursor.next();
	}
	
	curScore.endUndo();
	close();
};
//---------------------------------------------------------

var mscorePlugin = {
      menu: 'Plugins.Paste Rhythm',
      init: init,
      run:  pasteRhythm,
      onClose: close
      };

mscorePlugin;